==> macrofocus-docking-js-2021.2.4-sources.jar: jsMain/com/macrofocus/docking/js/JsDockingBar.kt <==
/*
 * Copyright (c) 2016 Macrofocus GmbH. All Rights Reserved.
 */
package com.macrofocus.docking.js

import com.macrofocus.common.command.Command
import com.macrofocus.common.properties.MutableProperty
import com.macrofocus.common.properties.SimpleArrayProperty
import com.macrofocus.common.properties.SimpleProperty
import com.macrofocus.docking.Dockable
import com.macrofocus.docking.DockingAnchor
import com.macrofocus.docking.DockingBar
import com.macrofocus.docking.DockingState
import js.objects.jso
import org.mkui.component.CPComponent
import org.mkui.component.ReactComponent
import org.mkui.react.toState
import react.FC
import react.Props
import react.dom.html.ReactHTML
import react.dom.html.ReactHTML.div
import web.cssom.*

class JsDockingBar(private val container: DockingContainer, private val orientation: DockingAnchor) : DockingBar<CPComponent> {
    private val orientationProperty : MutableProperty<DockingAnchor> = SimpleProperty<DockingAnchor>(orientation)
    private val components = SimpleArrayProperty<CPComponent>(arrayOf())

    override val nativeComponent: CPComponent = ReactComponent(FC<Props> {
        val (orientation, _) = orientationProperty.toState()
        val (getComponent, _) = components.toState()

        div{
            className = ClassName("buttonArea")

            style = jso {
                display = if (orientation == DockingAnchor.LEFT || orientation == DockingAnchor.RIGHT) Display.inlineBlock else Display.inlineFlex
            }

            for (c in getComponent) {
                c.nativeComponent()
            }
        }
    })

    override val dockables: MutableList<Dockable<CPComponent>?>?
    private val dockingButtons: MutableMap<Dockable<CPComponent>, DockingButton>
    private val dockingStates: MutableMap<Dockable<CPComponent>, DockingState>

    init {
        dockables = ArrayList()
        dockingButtons = HashMap()
        dockingStates = HashMap()

        //        nativeComponent.setStyle("-fx-background-color: #778999;");
    }

    override fun attach(dockable: Dockable<CPComponent>) {
        dockable.dockingBar = this

        val first = dockables!!.isEmpty()
        dockables.add(dockable)

        val button = DockingButton(orientation)
        button.text = dockable.shortTitle
        if (dockable.iconURL != null) {
        }
        dockingButtons[dockable] = button

        button.command = Command { setActive(dockable, button.selected) }
//        button.onAction = EventHandler { event: ActionEvent? -> setActive(dockable, button.isSelected) }

        components.append(button)

        val state = DockingState()
        dockingStates[dockable] = state

        if (first) {
            setActive(dockable, true)
        }
    }

    override fun detach(dockable: Dockable<CPComponent>) {
        setActive(dockable, false)
        dockables!!.remove(dockable)
        dockingButtons.remove(dockable)
        dockingStates.remove(dockable)
    }

    override fun removeAll() {
    }

    override fun isActive(dockable: Dockable<CPComponent>): Boolean {
        val state = dockingStates[dockable]
        return state!!.isActive
    }

    override fun setActive(dockable: Dockable<CPComponent>, active: Boolean) {
        val state = dockingStates[dockable]

        if (!state!!.isFloating) {
            for (d in dockables!!) {
                val s = dockingStates[d]

                if (s!!.isActive) {
                    s.isActive = d === dockable && active
                    val button = dockingButtons[d]
                    button!!.selected = d === dockable && active
                    container.remove(d!!.component)
                }
            }
            if (active) {
                state.isActive = true
                container.center = dockable.component
                container.visible = true
                val button = dockingButtons[dockable]
                button!!.selected = true
            } else {
                container.visible = false
            }
        } else {
//            SwingUtilities.windowForComponent(dockable.getContainer()).toFront();
            val button = dockingButtons[dockable]
            button!!.selected = false
        }
    }

    override fun setFloating(dockable: Dockable<CPComponent>, floating: Boolean) {
    }

    override fun setSliding(dockable: Dockable<CPComponent>, sliding: Boolean) {
    }

    override fun dispose() {
    }
}

==> macrofocus-docking-js-2025.0.3-sources.jar: jsMain/com/macrofocus/docking/js/JsDockingBar.kt <==
/*
 * Copyright (c) 2016 Macrofocus GmbH. All Rights Reserved.
 */
package com.macrofocus.docking.js

import com.macrofocus.common.command.Command
import com.macrofocus.common.properties.MutableProperty
import com.macrofocus.common.properties.SimpleArrayProperty
import com.macrofocus.common.properties.SimpleProperty
import com.macrofocus.docking.Dockable
import com.macrofocus.docking.DockingAnchor
import com.macrofocus.docking.DockingBar
import com.macrofocus.docking.DockingState
import js.objects.unsafeJso
import org.mkui.component.CPComponent
import org.mkui.component.ReactComponent
import org.mkui.react.toState
import react.FC
import react.Props
import react.dom.html.ReactHTML.div
import web.cssom.ClassName
import web.cssom.Display
import web.cssom.Position
import web.cssom.px

class JsDockingBar(private val container: DockingContainer, private val orientation: DockingAnchor) : DockingBar<CPComponent> {
    private val orientationProperty : MutableProperty<DockingAnchor> = SimpleProperty<DockingAnchor>(orientation)
    private val components = SimpleArrayProperty<CPComponent>(arrayOf())

    override val nativeComponent: CPComponent = ReactComponent(FC<Props> {
        val (orientation, _) = orientationProperty.toState()
        val (getComponent, _) = components.toState()

        div{
            className = ClassName("buttonArea")

            style = unsafeJso {
                position = Position.relative
                display = if (orientation == DockingAnchor.LEFT || orientation == DockingAnchor.RIGHT) Display.inlineBlock else Display.inlineFlex
                top = 0.px
                bottom = 0.px
                left = 0.px
                right = 0.px
            }

            for (c in getComponent) {
                c.nativeComponent()
            }
        }
    })

    override val dockables: MutableList<Dockable<CPComponent>?>?
    private val dockingButtons: MutableMap<Dockable<CPComponent>, DockingButton>
    private val dockingStates: MutableMap<Dockable<CPComponent>, DockingState>

    init {
        dockables = ArrayList()
        dockingButtons = HashMap()
        dockingStates = HashMap()

        //        nativeComponent.setStyle("-fx-background-color: #778999;");
    }

    override fun attach(dockable: Dockable<CPComponent>) {
        dockable.dockingBar = this

        val first = dockables!!.isEmpty()
        dockables.add(dockable)

        val button = DockingButton(orientation)
        button.text = dockable.shortTitle
        if (dockable.iconURL != null) {
        }
        dockingButtons[dockable] = button

        button.command = Command { setActive(dockable, button.selected) }
//        button.onAction = EventHandler { event: ActionEvent? -> setActive(dockable, button.isSelected) }

        components.append(button)

        val state = DockingState()
        dockingStates[dockable] = state

        if (first) {
            setActive(dockable, true)
        }
    }

    override fun detach(dockable: Dockable<CPComponent>) {
        setActive(dockable, false)
        dockables!!.remove(dockable)
        dockingButtons.remove(dockable)
        dockingStates.remove(dockable)
    }

    override fun removeAll() {
    }

    override fun isActive(dockable: Dockable<CPComponent>): Boolean {
        val state = dockingStates[dockable]
        return state!!.isActive
    }

    override fun setActive(dockable: Dockable<CPComponent>, active: Boolean) {
        val state = dockingStates[dockable]

        if (!state!!.isFloating) {
            for (d in dockables!!) {
                val s = dockingStates[d]

                if (s!!.isActive) {
                    s.isActive = d === dockable && active
                    val button = dockingButtons[d]
                    button!!.selected = d === dockable && active
                    container.remove(d!!.component)
                }
            }
            if (active) {
                state.isActive = true
                container.center = dockable.component
                container.visible = true
                val button = dockingButtons[dockable]
                button!!.selected = true
            } else {
                container.visible = false
            }
        } else {
//            SwingUtilities.windowForComponent(dockable.getContainer()).toFront();
            val button = dockingButtons[dockable]
            button!!.selected = false
        }
    }

    override fun setFloating(dockable: Dockable<CPComponent>, floating: Boolean) {
    }

    override fun setSliding(dockable: Dockable<CPComponent>, sliding: Boolean) {
    }

    override fun dispose() {
    }
}
